##############################################################################
# 
# Zope Public License (ZPL) Version 1.0
# -------------------------------------
# 
# Copyright (c) Digital Creations.  All rights reserved.
# 
# This license has been certified as Open Source(tm).
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
# 
# 1. Redistributions in source code must retain the above copyright
#    notice, this list of conditions, and the following disclaimer.
# 
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions, and the following disclaimer in
#    the documentation and/or other materials provided with the
#    distribution.
# 
# 3. Digital Creations requests that attribution be given to Zope
#    in any manner possible. Zope includes a "Powered by Zope"
#    button that is installed by default. While it is not a license
#    violation to remove this button, it is requested that the
#    attribution remain. A significant investment has been put
#    into Zope, and this effort will continue if the Zope community
#    continues to grow. This is one way to assure that growth.
# 
# 4. All advertising materials and documentation mentioning
#    features derived from or use of this software must display
#    the following acknowledgement:
# 
#      "This product includes software developed by Digital Creations
#      for use in the Z Object Publishing Environment
#      (http://www.zope.org/)."
# 
#    In the event that the product being advertised includes an
#    intact Zope distribution (with copyright and license included)
#    then this clause is waived.
# 
# 5. Names associated with Zope or Digital Creations must not be used to
#    endorse or promote products derived from this software without
#    prior written permission from Digital Creations.
# 
# 6. Modified redistributions of any form whatsoever must retain
#    the following acknowledgment:
# 
#      "This product includes software developed by Digital Creations
#      for use in the Z Object Publishing Environment
#      (http://www.zope.org/)."
# 
#    Intact (re-)distributions of any official Zope release do not
#    require an external acknowledgement.
# 
# 7. Modifications are encouraged but must be packaged separately as
#    patches to official Zope releases.  Distributions that do not
#    clearly separate the patches from the original work must be clearly
#    labeled as unofficial distributions.  Modifications which do not
#    carry the name Zope may be packaged in any form, as long as they
#    conform to all of the clauses above.
# 
# 
# Disclaimer
# 
#   THIS SOFTWARE IS PROVIDED BY DIGITAL CREATIONS ``AS IS'' AND ANY
#   EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
#   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
#   PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL DIGITAL CREATIONS OR ITS
#   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
#   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
#   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
#   ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
#   OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
#   OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
#   SUCH DAMAGE.
# 
# 
# This software consists of contributions made by Digital Creations and
# many individuals on behalf of Digital Creations.  Specific
# attributions are listed in the accompanying credits file.
# 
##############################################################################
#
# Copyright (c) 2000 Andy McKay
# All rights reserved.
# 
# Distributed under the Zope Public License (above)
#
##############################################################################

__version__ = '0.1'

from Globals import HTMLFile      
from Globals import MessageDialog 
from Globals import Persistent    

import OFS.SimpleItem
import Acquisition
import AccessControl.Role
import OFS.PropertyManager

import os
import string
import Globals # so I can get Globals data_dir
import time
import urllib

manage_addZPMForm = HTMLFile('ZPM', globals()) 

def manage_addZPM(self, id='', title='', REQUEST=None):
    ''' Adds a new object '''
    if id == '':    id = str(self.counter())
    obj = ZPM(id, title)
    self._setObject(id, obj)
    if REQUEST is not None:
            return self.manage_main(self, REQUEST)
    else:
        return id

class ZPM(OFS.SimpleItem.Item,  Persistent, Acquisition.Implicit, AccessControl.Role.RoleManager):
    meta_type = 'ZPM' 
    
    ZPMStoreURL = 'http://www.agmweb.ca/Zope/products/data'
    check_html = HTMLFile('ZPMCheck', globals()) 
    index_html = HTMLFile('ZPMIndex', globals()) 
    
    _properties = ( {'id':'ZPMStoreURL', 'type': 'string', 'mode': 'w'}, )
    manage_options = ( {'label':'View', 'action':'index_html',}, {'label':'Check Products', 'action':'check_html',}, ) + OFS.SimpleItem.Item.manage_options
        
    __ac_permissions__ = ()

    def list_products(self):
        ''' docstring '''
        l = []
        for o in self.Control_Panel.Products._objects:
            l.append(o['id'])
        return l
        
    def check_products(self):
        ''' docstring '''
        lines = urllib.urlopen('%s/%s/index_xml' % (self.ZPMStoreURL, self.REQUEST['product_to_check'])).readlines()
        
        for line in lines:
            if string.find(line, '<H2>Zope Error</H2>') > -1:
                return
        
        info = {}
        for line in lines:
            print line
            tag = self._find_tag(line)
            if tag != 'product':
                info[tag] = self._parse_line(line, tag)
        
        return info
    
    def _find_tag(self, line):
        return str(line[string.find(line, '<')+1:string.find(line, '>')])
            
    def _parse_line(self, line, thing):
        if string.find(line, '<%s>' % thing) > -1: return self._parse_xml(line)
        else: return None
        
    def _parse_xml(self, line):
        return str(line[string.find(line, '>')+1:string.rfind(line, '<')])


